drawing Package
===============

:mod:`drawing` Package
----------------------

.. automodule:: hyperspy.drawing
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`image` Module
-------------------

.. automodule:: hyperspy.drawing.image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mpl_hie` Module
---------------------

.. automodule:: hyperspy.drawing.mpl_hie
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mpl_hse` Module
---------------------

.. automodule:: hyperspy.drawing.mpl_hse
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`signal` Module
--------------------

.. automodule:: hyperspy.drawing.signal
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`spectrum` Module
----------------------

.. automodule:: hyperspy.drawing.spectrum
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: hyperspy.drawing.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`widgets` Module
---------------------

.. automodule:: hyperspy.drawing.widgets
    :members:
    :undoc-members:
    :show-inheritance:

